# mijin-openapi-client
OpenAPI Specification of catapult-rest

The `mijin_openapi_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.4
- Package version: 1.0.0
- Generator version: 7.12.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with mijin-openapi-client,
you can run the following:

```python

import mijin_openapi_client
from mijin_openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:3000
# See configuration.py for a list of all supported configuration parameters.
configuration = mijin_openapi_client.Configuration(
    host = "http://localhost:3000"
)



# Enter a context with an instance of the API client
with mijin_openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = mijin_openapi_client.AccountRoutesApi(api_client)
    account_id = 'account_id_example' # str | Account public key or address encoded using a 32-character set.

    try:
        # Get account information
        api_response = api_instance.get_account_info(account_id)
        print("The response of AccountRoutesApi->get_account_info:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountRoutesApi->get_account_info: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:3000*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountRoutesApi* | [**get_account_info**](mijin_openapi_client/docs/AccountRoutesApi.md#get_account_info) | **GET** /accounts/{accountId} | Get account information
*AccountRoutesApi* | [**get_account_info_merkle**](mijin_openapi_client/docs/AccountRoutesApi.md#get_account_info_merkle) | **GET** /accounts/{accountId}/merkle | Get account merkle information
*AccountRoutesApi* | [**get_accounts_info**](mijin_openapi_client/docs/AccountRoutesApi.md#get_accounts_info) | **POST** /accounts | Get accounts information
*AccountRoutesApi* | [**search_accounts**](mijin_openapi_client/docs/AccountRoutesApi.md#search_accounts) | **GET** /accounts | Search accounts
*BlockRoutesApi* | [**get_block_by_height**](mijin_openapi_client/docs/BlockRoutesApi.md#get_block_by_height) | **GET** /blocks/{height} | Get block information
*BlockRoutesApi* | [**get_merkle_receipts**](mijin_openapi_client/docs/BlockRoutesApi.md#get_merkle_receipts) | **GET** /blocks/{height}/statements/{hash}/merkle | Get the merkle path for a given a receipt statement hash and block
*BlockRoutesApi* | [**get_merkle_transaction**](mijin_openapi_client/docs/BlockRoutesApi.md#get_merkle_transaction) | **GET** /blocks/{height}/transactions/{hash}/merkle | Get the merkle path for a given a transaction and block
*BlockRoutesApi* | [**search_blocks**](mijin_openapi_client/docs/BlockRoutesApi.md#search_blocks) | **GET** /blocks | Search blocks
*ChainRoutesApi* | [**get_chain_info**](mijin_openapi_client/docs/ChainRoutesApi.md#get_chain_info) | **GET** /chain/info | Get the current information of the chain
*FinalizationRoutesApi* | [**get_finalization_proof_at_epoch**](mijin_openapi_client/docs/FinalizationRoutesApi.md#get_finalization_proof_at_epoch) | **GET** /finalization/proof/epoch/{epoch} | Get finalization proof
*FinalizationRoutesApi* | [**get_finalization_proof_at_height**](mijin_openapi_client/docs/FinalizationRoutesApi.md#get_finalization_proof_at_height) | **GET** /finalization/proof/height/{height} | Get finalization proof
*HashLockRoutesApi* | [**get_hash_lock**](mijin_openapi_client/docs/HashLockRoutesApi.md#get_hash_lock) | **GET** /lock/hash/{hash} | Get hash lock information
*HashLockRoutesApi* | [**get_hash_lock_merkle**](mijin_openapi_client/docs/HashLockRoutesApi.md#get_hash_lock_merkle) | **GET** /lock/hash/{hash}/merkle | Get hash lock merkle information
*HashLockRoutesApi* | [**search_hash_lock**](mijin_openapi_client/docs/HashLockRoutesApi.md#search_hash_lock) | **GET** /lock/hash | Search hash lock entries
*MetadataRoutesApi* | [**get_metadata**](mijin_openapi_client/docs/MetadataRoutesApi.md#get_metadata) | **GET** /metadata/{compositeHash} | Get metadata information
*MetadataRoutesApi* | [**get_metadata_merkle**](mijin_openapi_client/docs/MetadataRoutesApi.md#get_metadata_merkle) | **GET** /metadata/{compositeHash}/merkle | Get metadata merkle information
*MetadataRoutesApi* | [**search_metadata_entries**](mijin_openapi_client/docs/MetadataRoutesApi.md#search_metadata_entries) | **GET** /metadata | Search metadata entries
*MosaicRoutesApi* | [**get_mosaic**](mijin_openapi_client/docs/MosaicRoutesApi.md#get_mosaic) | **GET** /mosaics/{mosaicId} | Get mosaic information
*MosaicRoutesApi* | [**get_mosaic_merkle**](mijin_openapi_client/docs/MosaicRoutesApi.md#get_mosaic_merkle) | **GET** /mosaics/{mosaicId}/merkle | Get mosaic merkle information
*MosaicRoutesApi* | [**get_mosaics**](mijin_openapi_client/docs/MosaicRoutesApi.md#get_mosaics) | **POST** /mosaics | Get mosaics information for an array of mosaics
*MosaicRoutesApi* | [**search_mosaics**](mijin_openapi_client/docs/MosaicRoutesApi.md#search_mosaics) | **GET** /mosaics | Search mosaics
*MultisigRoutesApi* | [**get_account_multisig**](mijin_openapi_client/docs/MultisigRoutesApi.md#get_account_multisig) | **GET** /account/{address}/multisig | Get multisig account information
*MultisigRoutesApi* | [**get_account_multisig_graph**](mijin_openapi_client/docs/MultisigRoutesApi.md#get_account_multisig_graph) | **GET** /account/{address}/multisig/graph | Get multisig account graph information
*MultisigRoutesApi* | [**get_account_multisig_merkle**](mijin_openapi_client/docs/MultisigRoutesApi.md#get_account_multisig_merkle) | **GET** /account/{address}/multisig/merkle | Get multisig account merkle information
*NamespaceRoutesApi* | [**get_accounts_names**](mijin_openapi_client/docs/NamespaceRoutesApi.md#get_accounts_names) | **POST** /namespaces/account/names | Get readable names for a set of accountIds
*NamespaceRoutesApi* | [**get_mosaics_names**](mijin_openapi_client/docs/NamespaceRoutesApi.md#get_mosaics_names) | **POST** /namespaces/mosaic/names | Get readable names for a set of mosaics
*NamespaceRoutesApi* | [**get_namespace**](mijin_openapi_client/docs/NamespaceRoutesApi.md#get_namespace) | **GET** /namespaces/{namespaceId} | Get namespace information
*NamespaceRoutesApi* | [**get_namespace_merkle**](mijin_openapi_client/docs/NamespaceRoutesApi.md#get_namespace_merkle) | **GET** /namespaces/{namespaceId}/merkle | Get namespace merkle information
*NamespaceRoutesApi* | [**get_namespaces_names**](mijin_openapi_client/docs/NamespaceRoutesApi.md#get_namespaces_names) | **POST** /namespaces/names | Get readable names for a set of namespaces
*NamespaceRoutesApi* | [**search_namespaces**](mijin_openapi_client/docs/NamespaceRoutesApi.md#search_namespaces) | **GET** /namespaces | Search namespaces
*NetworkRoutesApi* | [**get_network_properties**](mijin_openapi_client/docs/NetworkRoutesApi.md#get_network_properties) | **GET** /network/properties | Get the network properties
*NetworkRoutesApi* | [**get_network_type**](mijin_openapi_client/docs/NetworkRoutesApi.md#get_network_type) | **GET** /network | Get the current network type of the chain
*NetworkRoutesApi* | [**get_rental_fees**](mijin_openapi_client/docs/NetworkRoutesApi.md#get_rental_fees) | **GET** /network/fees/rental | Get rental fees information
*NetworkRoutesApi* | [**get_transaction_fees**](mijin_openapi_client/docs/NetworkRoutesApi.md#get_transaction_fees) | **GET** /network/fees/transaction | Get transaction fees information
*NodeRoutesApi* | [**get_node_health**](mijin_openapi_client/docs/NodeRoutesApi.md#get_node_health) | **GET** /node/health | Get the node health information
*NodeRoutesApi* | [**get_node_info**](mijin_openapi_client/docs/NodeRoutesApi.md#get_node_info) | **GET** /node/info | Get the node information
*NodeRoutesApi* | [**get_node_peers**](mijin_openapi_client/docs/NodeRoutesApi.md#get_node_peers) | **GET** /node/peers | Get peers information
*NodeRoutesApi* | [**get_node_storage**](mijin_openapi_client/docs/NodeRoutesApi.md#get_node_storage) | **GET** /node/storage | Get the storage information of the node
*NodeRoutesApi* | [**get_node_time**](mijin_openapi_client/docs/NodeRoutesApi.md#get_node_time) | **GET** /node/time | Get the node time
*NodeRoutesApi* | [**get_server_info**](mijin_openapi_client/docs/NodeRoutesApi.md#get_server_info) | **GET** /node/server | Get the version of the running REST component
*NodeRoutesApi* | [**get_unlocked_account**](mijin_openapi_client/docs/NodeRoutesApi.md#get_unlocked_account) | **GET** /node/unlockedaccount | Get the unlocked harvesting account public keys.
*ReceiptRoutesApi* | [**search_address_resolution_statements**](mijin_openapi_client/docs/ReceiptRoutesApi.md#search_address_resolution_statements) | **GET** /statements/resolutions/address | Get receipts address resolution statements
*ReceiptRoutesApi* | [**search_mosaic_resolution_statements**](mijin_openapi_client/docs/ReceiptRoutesApi.md#search_mosaic_resolution_statements) | **GET** /statements/resolutions/mosaic | Get receipts mosaic resolution statements
*ReceiptRoutesApi* | [**search_receipts**](mijin_openapi_client/docs/ReceiptRoutesApi.md#search_receipts) | **GET** /statements/transaction | Search transaction statements
*RestrictionAccountRoutesApi* | [**get_account_restrictions**](mijin_openapi_client/docs/RestrictionAccountRoutesApi.md#get_account_restrictions) | **GET** /restrictions/account/{address} | Get the account restrictions
*RestrictionAccountRoutesApi* | [**get_account_restrictions_merkle**](mijin_openapi_client/docs/RestrictionAccountRoutesApi.md#get_account_restrictions_merkle) | **GET** /restrictions/account/{address}/merkle | Get the account restrictions merkle
*RestrictionAccountRoutesApi* | [**search_account_restrictions**](mijin_openapi_client/docs/RestrictionAccountRoutesApi.md#search_account_restrictions) | **GET** /restrictions/account | Search account restrictions
*RestrictionMosaicRoutesApi* | [**get_mosaic_restrictions**](mijin_openapi_client/docs/RestrictionMosaicRoutesApi.md#get_mosaic_restrictions) | **GET** /restrictions/mosaic/{compositeHash} | Get the mosaic restrictions
*RestrictionMosaicRoutesApi* | [**get_mosaic_restrictions_merkle**](mijin_openapi_client/docs/RestrictionMosaicRoutesApi.md#get_mosaic_restrictions_merkle) | **GET** /restrictions/mosaic/{compositeHash}/merkle | Get the mosaic restrictions merkle
*RestrictionMosaicRoutesApi* | [**search_mosaic_restrictions**](mijin_openapi_client/docs/RestrictionMosaicRoutesApi.md#search_mosaic_restrictions) | **GET** /restrictions/mosaic | Search mosaic restrictions
*SecretLockRoutesApi* | [**get_secret_lock**](mijin_openapi_client/docs/SecretLockRoutesApi.md#get_secret_lock) | **GET** /lock/secret/{compositeHash} | Get secret lock information
*SecretLockRoutesApi* | [**get_secret_lock_merkle**](mijin_openapi_client/docs/SecretLockRoutesApi.md#get_secret_lock_merkle) | **GET** /lock/secret/{compositeHash}/merkle | Get secret lock merkle information
*SecretLockRoutesApi* | [**search_secret_lock**](mijin_openapi_client/docs/SecretLockRoutesApi.md#search_secret_lock) | **GET** /lock/secret | Search secret lock entries
*TransactionRoutesApi* | [**announce_cosignature_transaction**](mijin_openapi_client/docs/TransactionRoutesApi.md#announce_cosignature_transaction) | **PUT** /transactions/cosignature | Announce a cosignature transaction
*TransactionRoutesApi* | [**announce_partial_transaction**](mijin_openapi_client/docs/TransactionRoutesApi.md#announce_partial_transaction) | **PUT** /transactions/partial | Announce an aggregate bonded transaction
*TransactionRoutesApi* | [**announce_transaction**](mijin_openapi_client/docs/TransactionRoutesApi.md#announce_transaction) | **PUT** /transactions | Announce a new transaction
*TransactionRoutesApi* | [**get_confirmed_transaction**](mijin_openapi_client/docs/TransactionRoutesApi.md#get_confirmed_transaction) | **GET** /transactions/confirmed/{transactionId} | Get confirmed transaction information
*TransactionRoutesApi* | [**get_confirmed_transactions**](mijin_openapi_client/docs/TransactionRoutesApi.md#get_confirmed_transactions) | **POST** /transactions/confirmed | Get confirmed trasactions information
*TransactionRoutesApi* | [**get_partial_transaction**](mijin_openapi_client/docs/TransactionRoutesApi.md#get_partial_transaction) | **GET** /transactions/partial/{transactionId} | Get partial transaction information
*TransactionRoutesApi* | [**get_partial_transactions**](mijin_openapi_client/docs/TransactionRoutesApi.md#get_partial_transactions) | **POST** /transactions/partial | Get partial trasactions information
*TransactionRoutesApi* | [**get_unconfirmed_transaction**](mijin_openapi_client/docs/TransactionRoutesApi.md#get_unconfirmed_transaction) | **GET** /transactions/unconfirmed/{transactionId} | Get unconfirmed transaction information
*TransactionRoutesApi* | [**get_unconfirmed_transactions**](mijin_openapi_client/docs/TransactionRoutesApi.md#get_unconfirmed_transactions) | **POST** /transactions/unconfirmed | Get unconfirmed trasactions information
*TransactionRoutesApi* | [**search_confirmed_transactions**](mijin_openapi_client/docs/TransactionRoutesApi.md#search_confirmed_transactions) | **GET** /transactions/confirmed | Search confirmed transactions
*TransactionRoutesApi* | [**search_partial_transactions**](mijin_openapi_client/docs/TransactionRoutesApi.md#search_partial_transactions) | **GET** /transactions/partial | Search partial transactions
*TransactionRoutesApi* | [**search_unconfirmed_transactions**](mijin_openapi_client/docs/TransactionRoutesApi.md#search_unconfirmed_transactions) | **GET** /transactions/unconfirmed | Search unconfirmed transactions
*TransactionStatusRoutesApi* | [**get_transaction_status**](mijin_openapi_client/docs/TransactionStatusRoutesApi.md#get_transaction_status) | **GET** /transactionStatus/{hash} | Get transaction status
*TransactionStatusRoutesApi* | [**get_transaction_statuses**](mijin_openapi_client/docs/TransactionStatusRoutesApi.md#get_transaction_statuses) | **POST** /transactionStatus | Get transaction statuses


## Documentation For Models

 - [AccountAddressRestrictionTransactionBodyDTO](mijin_openapi_client/docs/AccountAddressRestrictionTransactionBodyDTO.md)
 - [AccountAddressRestrictionTransactionDTO](mijin_openapi_client/docs/AccountAddressRestrictionTransactionDTO.md)
 - [AccountDTO](mijin_openapi_client/docs/AccountDTO.md)
 - [AccountIds](mijin_openapi_client/docs/AccountIds.md)
 - [AccountInfoDTO](mijin_openapi_client/docs/AccountInfoDTO.md)
 - [AccountKeyLinkNetworkPropertiesDTO](mijin_openapi_client/docs/AccountKeyLinkNetworkPropertiesDTO.md)
 - [AccountKeyLinkTransactionBodyDTO](mijin_openapi_client/docs/AccountKeyLinkTransactionBodyDTO.md)
 - [AccountKeyLinkTransactionDTO](mijin_openapi_client/docs/AccountKeyLinkTransactionDTO.md)
 - [AccountKeyTypeFlagsEnum](mijin_openapi_client/docs/AccountKeyTypeFlagsEnum.md)
 - [AccountLinkPublicKeyDTO](mijin_openapi_client/docs/AccountLinkPublicKeyDTO.md)
 - [AccountLinkVotingKeyDTO](mijin_openapi_client/docs/AccountLinkVotingKeyDTO.md)
 - [AccountLinkVotingKeysDTO](mijin_openapi_client/docs/AccountLinkVotingKeysDTO.md)
 - [AccountMetadataTransactionBodyDTO](mijin_openapi_client/docs/AccountMetadataTransactionBodyDTO.md)
 - [AccountMetadataTransactionDTO](mijin_openapi_client/docs/AccountMetadataTransactionDTO.md)
 - [AccountMosaicRestrictionTransactionBodyDTO](mijin_openapi_client/docs/AccountMosaicRestrictionTransactionBodyDTO.md)
 - [AccountMosaicRestrictionTransactionDTO](mijin_openapi_client/docs/AccountMosaicRestrictionTransactionDTO.md)
 - [AccountNamesDTO](mijin_openapi_client/docs/AccountNamesDTO.md)
 - [AccountOperationRestrictionTransactionBodyDTO](mijin_openapi_client/docs/AccountOperationRestrictionTransactionBodyDTO.md)
 - [AccountOperationRestrictionTransactionDTO](mijin_openapi_client/docs/AccountOperationRestrictionTransactionDTO.md)
 - [AccountOrderByEnum](mijin_openapi_client/docs/AccountOrderByEnum.md)
 - [AccountPage](mijin_openapi_client/docs/AccountPage.md)
 - [AccountRestrictionDTO](mijin_openapi_client/docs/AccountRestrictionDTO.md)
 - [AccountRestrictionDTOValuesInner](mijin_openapi_client/docs/AccountRestrictionDTOValuesInner.md)
 - [AccountRestrictionFlagsEnum](mijin_openapi_client/docs/AccountRestrictionFlagsEnum.md)
 - [AccountRestrictionNetworkPropertiesDTO](mijin_openapi_client/docs/AccountRestrictionNetworkPropertiesDTO.md)
 - [AccountRestrictionsDTO](mijin_openapi_client/docs/AccountRestrictionsDTO.md)
 - [AccountRestrictionsInfoDTO](mijin_openapi_client/docs/AccountRestrictionsInfoDTO.md)
 - [AccountRestrictionsPage](mijin_openapi_client/docs/AccountRestrictionsPage.md)
 - [AccountTypeEnum](mijin_openapi_client/docs/AccountTypeEnum.md)
 - [AccountsNamesDTO](mijin_openapi_client/docs/AccountsNamesDTO.md)
 - [ActivityBucketDTO](mijin_openapi_client/docs/ActivityBucketDTO.md)
 - [AddressAliasTransactionBodyDTO](mijin_openapi_client/docs/AddressAliasTransactionBodyDTO.md)
 - [AddressAliasTransactionDTO](mijin_openapi_client/docs/AddressAliasTransactionDTO.md)
 - [Addresses](mijin_openapi_client/docs/Addresses.md)
 - [AggregateNetworkPropertiesDTO](mijin_openapi_client/docs/AggregateNetworkPropertiesDTO.md)
 - [AggregateTransactionBodyDTO](mijin_openapi_client/docs/AggregateTransactionBodyDTO.md)
 - [AggregateTransactionBodyExtendedDTO](mijin_openapi_client/docs/AggregateTransactionBodyExtendedDTO.md)
 - [AggregateTransactionDTO](mijin_openapi_client/docs/AggregateTransactionDTO.md)
 - [AggregateTransactionExtendedDTO](mijin_openapi_client/docs/AggregateTransactionExtendedDTO.md)
 - [AliasActionEnum](mijin_openapi_client/docs/AliasActionEnum.md)
 - [AliasDTO](mijin_openapi_client/docs/AliasDTO.md)
 - [AliasTypeEnum](mijin_openapi_client/docs/AliasTypeEnum.md)
 - [AnnounceTransactionInfoDTO](mijin_openapi_client/docs/AnnounceTransactionInfoDTO.md)
 - [BalanceChangeReceiptDTO](mijin_openapi_client/docs/BalanceChangeReceiptDTO.md)
 - [BalanceTransferReceiptDTO](mijin_openapi_client/docs/BalanceTransferReceiptDTO.md)
 - [BlockDTO](mijin_openapi_client/docs/BlockDTO.md)
 - [BlockInfoDTO](mijin_openapi_client/docs/BlockInfoDTO.md)
 - [BlockInfoDTOBlock](mijin_openapi_client/docs/BlockInfoDTOBlock.md)
 - [BlockMetaDTO](mijin_openapi_client/docs/BlockMetaDTO.md)
 - [BlockOrderByEnum](mijin_openapi_client/docs/BlockOrderByEnum.md)
 - [BlockPage](mijin_openapi_client/docs/BlockPage.md)
 - [BmTreeSignature](mijin_openapi_client/docs/BmTreeSignature.md)
 - [ChainInfoDTO](mijin_openapi_client/docs/ChainInfoDTO.md)
 - [ChainPropertiesDTO](mijin_openapi_client/docs/ChainPropertiesDTO.md)
 - [CommunicationTimestampsDTO](mijin_openapi_client/docs/CommunicationTimestampsDTO.md)
 - [Cosignature](mijin_openapi_client/docs/Cosignature.md)
 - [CosignatureDTO](mijin_openapi_client/docs/CosignatureDTO.md)
 - [DeploymentDTO](mijin_openapi_client/docs/DeploymentDTO.md)
 - [EmbeddedAccountAddressRestrictionTransactionDTO](mijin_openapi_client/docs/EmbeddedAccountAddressRestrictionTransactionDTO.md)
 - [EmbeddedAccountKeyLinkTransactionDTO](mijin_openapi_client/docs/EmbeddedAccountKeyLinkTransactionDTO.md)
 - [EmbeddedAccountMetadataTransactionDTO](mijin_openapi_client/docs/EmbeddedAccountMetadataTransactionDTO.md)
 - [EmbeddedAccountMosaicRestrictionTransactionDTO](mijin_openapi_client/docs/EmbeddedAccountMosaicRestrictionTransactionDTO.md)
 - [EmbeddedAccountOperationRestrictionTransactionDTO](mijin_openapi_client/docs/EmbeddedAccountOperationRestrictionTransactionDTO.md)
 - [EmbeddedAddressAliasTransactionDTO](mijin_openapi_client/docs/EmbeddedAddressAliasTransactionDTO.md)
 - [EmbeddedHashLockTransactionDTO](mijin_openapi_client/docs/EmbeddedHashLockTransactionDTO.md)
 - [EmbeddedMosaicAddressRestrictionTransactionDTO](mijin_openapi_client/docs/EmbeddedMosaicAddressRestrictionTransactionDTO.md)
 - [EmbeddedMosaicAliasTransactionDTO](mijin_openapi_client/docs/EmbeddedMosaicAliasTransactionDTO.md)
 - [EmbeddedMosaicDefinitionTransactionDTO](mijin_openapi_client/docs/EmbeddedMosaicDefinitionTransactionDTO.md)
 - [EmbeddedMosaicGlobalRestrictionTransactionDTO](mijin_openapi_client/docs/EmbeddedMosaicGlobalRestrictionTransactionDTO.md)
 - [EmbeddedMosaicMetadataTransactionDTO](mijin_openapi_client/docs/EmbeddedMosaicMetadataTransactionDTO.md)
 - [EmbeddedMosaicSupplyChangeTransactionDTO](mijin_openapi_client/docs/EmbeddedMosaicSupplyChangeTransactionDTO.md)
 - [EmbeddedMosaicSupplyRevocationTransactionDTO](mijin_openapi_client/docs/EmbeddedMosaicSupplyRevocationTransactionDTO.md)
 - [EmbeddedMultisigAccountModificationTransactionDTO](mijin_openapi_client/docs/EmbeddedMultisigAccountModificationTransactionDTO.md)
 - [EmbeddedNamespaceMetadataTransactionDTO](mijin_openapi_client/docs/EmbeddedNamespaceMetadataTransactionDTO.md)
 - [EmbeddedNamespaceRegistrationTransactionDTO](mijin_openapi_client/docs/EmbeddedNamespaceRegistrationTransactionDTO.md)
 - [EmbeddedNodeKeyLinkTransactionDTO](mijin_openapi_client/docs/EmbeddedNodeKeyLinkTransactionDTO.md)
 - [EmbeddedSecretLockTransactionDTO](mijin_openapi_client/docs/EmbeddedSecretLockTransactionDTO.md)
 - [EmbeddedSecretProofTransactionDTO](mijin_openapi_client/docs/EmbeddedSecretProofTransactionDTO.md)
 - [EmbeddedTransactionBodyDTO](mijin_openapi_client/docs/EmbeddedTransactionBodyDTO.md)
 - [EmbeddedTransactionDTO](mijin_openapi_client/docs/EmbeddedTransactionDTO.md)
 - [EmbeddedTransactionInfoDTO](mijin_openapi_client/docs/EmbeddedTransactionInfoDTO.md)
 - [EmbeddedTransactionInfoDTOTransaction](mijin_openapi_client/docs/EmbeddedTransactionInfoDTOTransaction.md)
 - [EmbeddedTransactionMetaDTO](mijin_openapi_client/docs/EmbeddedTransactionMetaDTO.md)
 - [EmbeddedTransferTransactionDTO](mijin_openapi_client/docs/EmbeddedTransferTransactionDTO.md)
 - [EmbeddedVotingKeyLinkTransactionDTO](mijin_openapi_client/docs/EmbeddedVotingKeyLinkTransactionDTO.md)
 - [EmbeddedVrfKeyLinkTransactionDTO](mijin_openapi_client/docs/EmbeddedVrfKeyLinkTransactionDTO.md)
 - [EntityDTO](mijin_openapi_client/docs/EntityDTO.md)
 - [FinalizationProofDTO](mijin_openapi_client/docs/FinalizationProofDTO.md)
 - [FinalizedBlockDTO](mijin_openapi_client/docs/FinalizedBlockDTO.md)
 - [HashLockEntryDTO](mijin_openapi_client/docs/HashLockEntryDTO.md)
 - [HashLockInfoDTO](mijin_openapi_client/docs/HashLockInfoDTO.md)
 - [HashLockNetworkPropertiesDTO](mijin_openapi_client/docs/HashLockNetworkPropertiesDTO.md)
 - [HashLockPage](mijin_openapi_client/docs/HashLockPage.md)
 - [HashLockTransactionBodyDTO](mijin_openapi_client/docs/HashLockTransactionBodyDTO.md)
 - [HashLockTransactionDTO](mijin_openapi_client/docs/HashLockTransactionDTO.md)
 - [ImportanceBlockDTO](mijin_openapi_client/docs/ImportanceBlockDTO.md)
 - [InflationReceiptDTO](mijin_openapi_client/docs/InflationReceiptDTO.md)
 - [LinkActionEnum](mijin_openapi_client/docs/LinkActionEnum.md)
 - [LockHashAlgorithmEnum](mijin_openapi_client/docs/LockHashAlgorithmEnum.md)
 - [LockStatus](mijin_openapi_client/docs/LockStatus.md)
 - [MerklePathItemDTO](mijin_openapi_client/docs/MerklePathItemDTO.md)
 - [MerkleProofInfoDTO](mijin_openapi_client/docs/MerkleProofInfoDTO.md)
 - [MerkleStateInfoDTO](mijin_openapi_client/docs/MerkleStateInfoDTO.md)
 - [MerkleStateInfoDTOTreeInner](mijin_openapi_client/docs/MerkleStateInfoDTOTreeInner.md)
 - [MerkleTreeBranchDTO](mijin_openapi_client/docs/MerkleTreeBranchDTO.md)
 - [MerkleTreeBranchLinkDTO](mijin_openapi_client/docs/MerkleTreeBranchLinkDTO.md)
 - [MerkleTreeLeafDTO](mijin_openapi_client/docs/MerkleTreeLeafDTO.md)
 - [MerkleTreeNodeTypeEnum](mijin_openapi_client/docs/MerkleTreeNodeTypeEnum.md)
 - [MessageGroup](mijin_openapi_client/docs/MessageGroup.md)
 - [MetadataEntryDTO](mijin_openapi_client/docs/MetadataEntryDTO.md)
 - [MetadataEntryDTOTargetId](mijin_openapi_client/docs/MetadataEntryDTOTargetId.md)
 - [MetadataInfoDTO](mijin_openapi_client/docs/MetadataInfoDTO.md)
 - [MetadataNetworkPropertiesDTO](mijin_openapi_client/docs/MetadataNetworkPropertiesDTO.md)
 - [MetadataPage](mijin_openapi_client/docs/MetadataPage.md)
 - [MetadataTypeEnum](mijin_openapi_client/docs/MetadataTypeEnum.md)
 - [ModelError](mijin_openapi_client/docs/ModelError.md)
 - [Mosaic](mijin_openapi_client/docs/Mosaic.md)
 - [MosaicAddressRestrictionDTO](mijin_openapi_client/docs/MosaicAddressRestrictionDTO.md)
 - [MosaicAddressRestrictionEntryDTO](mijin_openapi_client/docs/MosaicAddressRestrictionEntryDTO.md)
 - [MosaicAddressRestrictionEntryWrapperDTO](mijin_openapi_client/docs/MosaicAddressRestrictionEntryWrapperDTO.md)
 - [MosaicAddressRestrictionTransactionBodyDTO](mijin_openapi_client/docs/MosaicAddressRestrictionTransactionBodyDTO.md)
 - [MosaicAddressRestrictionTransactionDTO](mijin_openapi_client/docs/MosaicAddressRestrictionTransactionDTO.md)
 - [MosaicAliasTransactionBodyDTO](mijin_openapi_client/docs/MosaicAliasTransactionBodyDTO.md)
 - [MosaicAliasTransactionDTO](mijin_openapi_client/docs/MosaicAliasTransactionDTO.md)
 - [MosaicDTO](mijin_openapi_client/docs/MosaicDTO.md)
 - [MosaicDefinitionTransactionBodyDTO](mijin_openapi_client/docs/MosaicDefinitionTransactionBodyDTO.md)
 - [MosaicDefinitionTransactionDTO](mijin_openapi_client/docs/MosaicDefinitionTransactionDTO.md)
 - [MosaicExpiryReceiptDTO](mijin_openapi_client/docs/MosaicExpiryReceiptDTO.md)
 - [MosaicGlobalRestrictionDTO](mijin_openapi_client/docs/MosaicGlobalRestrictionDTO.md)
 - [MosaicGlobalRestrictionEntryDTO](mijin_openapi_client/docs/MosaicGlobalRestrictionEntryDTO.md)
 - [MosaicGlobalRestrictionEntryRestrictionDTO](mijin_openapi_client/docs/MosaicGlobalRestrictionEntryRestrictionDTO.md)
 - [MosaicGlobalRestrictionEntryWrapperDTO](mijin_openapi_client/docs/MosaicGlobalRestrictionEntryWrapperDTO.md)
 - [MosaicGlobalRestrictionTransactionBodyDTO](mijin_openapi_client/docs/MosaicGlobalRestrictionTransactionBodyDTO.md)
 - [MosaicGlobalRestrictionTransactionDTO](mijin_openapi_client/docs/MosaicGlobalRestrictionTransactionDTO.md)
 - [MosaicIds](mijin_openapi_client/docs/MosaicIds.md)
 - [MosaicInfoDTO](mijin_openapi_client/docs/MosaicInfoDTO.md)
 - [MosaicMetadataTransactionBodyDTO](mijin_openapi_client/docs/MosaicMetadataTransactionBodyDTO.md)
 - [MosaicMetadataTransactionDTO](mijin_openapi_client/docs/MosaicMetadataTransactionDTO.md)
 - [MosaicNamesDTO](mijin_openapi_client/docs/MosaicNamesDTO.md)
 - [MosaicNetworkPropertiesDTO](mijin_openapi_client/docs/MosaicNetworkPropertiesDTO.md)
 - [MosaicPage](mijin_openapi_client/docs/MosaicPage.md)
 - [MosaicRestrictionDTO](mijin_openapi_client/docs/MosaicRestrictionDTO.md)
 - [MosaicRestrictionEntryTypeEnum](mijin_openapi_client/docs/MosaicRestrictionEntryTypeEnum.md)
 - [MosaicRestrictionNetworkPropertiesDTO](mijin_openapi_client/docs/MosaicRestrictionNetworkPropertiesDTO.md)
 - [MosaicRestrictionTypeEnum](mijin_openapi_client/docs/MosaicRestrictionTypeEnum.md)
 - [MosaicRestrictionsPage](mijin_openapi_client/docs/MosaicRestrictionsPage.md)
 - [MosaicRestrictionsPageDataInner](mijin_openapi_client/docs/MosaicRestrictionsPageDataInner.md)
 - [MosaicSupplyChangeActionEnum](mijin_openapi_client/docs/MosaicSupplyChangeActionEnum.md)
 - [MosaicSupplyChangeTransactionBodyDTO](mijin_openapi_client/docs/MosaicSupplyChangeTransactionBodyDTO.md)
 - [MosaicSupplyChangeTransactionDTO](mijin_openapi_client/docs/MosaicSupplyChangeTransactionDTO.md)
 - [MosaicSupplyRevocationTransactionBodyDTO](mijin_openapi_client/docs/MosaicSupplyRevocationTransactionBodyDTO.md)
 - [MosaicSupplyRevocationTransactionDTO](mijin_openapi_client/docs/MosaicSupplyRevocationTransactionDTO.md)
 - [MosaicsNamesDTO](mijin_openapi_client/docs/MosaicsNamesDTO.md)
 - [MultisigAccountGraphInfoDTO](mijin_openapi_client/docs/MultisigAccountGraphInfoDTO.md)
 - [MultisigAccountInfoDTO](mijin_openapi_client/docs/MultisigAccountInfoDTO.md)
 - [MultisigAccountModificationTransactionBodyDTO](mijin_openapi_client/docs/MultisigAccountModificationTransactionBodyDTO.md)
 - [MultisigAccountModificationTransactionDTO](mijin_openapi_client/docs/MultisigAccountModificationTransactionDTO.md)
 - [MultisigDTO](mijin_openapi_client/docs/MultisigDTO.md)
 - [MultisigNetworkPropertiesDTO](mijin_openapi_client/docs/MultisigNetworkPropertiesDTO.md)
 - [NamespaceDTO](mijin_openapi_client/docs/NamespaceDTO.md)
 - [NamespaceExpiryReceiptDTO](mijin_openapi_client/docs/NamespaceExpiryReceiptDTO.md)
 - [NamespaceIds](mijin_openapi_client/docs/NamespaceIds.md)
 - [NamespaceInfoDTO](mijin_openapi_client/docs/NamespaceInfoDTO.md)
 - [NamespaceMetaDTO](mijin_openapi_client/docs/NamespaceMetaDTO.md)
 - [NamespaceMetadataTransactionBodyDTO](mijin_openapi_client/docs/NamespaceMetadataTransactionBodyDTO.md)
 - [NamespaceMetadataTransactionDTO](mijin_openapi_client/docs/NamespaceMetadataTransactionDTO.md)
 - [NamespaceNameDTO](mijin_openapi_client/docs/NamespaceNameDTO.md)
 - [NamespaceNetworkPropertiesDTO](mijin_openapi_client/docs/NamespaceNetworkPropertiesDTO.md)
 - [NamespacePage](mijin_openapi_client/docs/NamespacePage.md)
 - [NamespaceRegistrationTransactionBodyDTO](mijin_openapi_client/docs/NamespaceRegistrationTransactionBodyDTO.md)
 - [NamespaceRegistrationTransactionDTO](mijin_openapi_client/docs/NamespaceRegistrationTransactionDTO.md)
 - [NamespaceRegistrationTypeEnum](mijin_openapi_client/docs/NamespaceRegistrationTypeEnum.md)
 - [NetworkConfigurationDTO](mijin_openapi_client/docs/NetworkConfigurationDTO.md)
 - [NetworkPropertiesDTO](mijin_openapi_client/docs/NetworkPropertiesDTO.md)
 - [NetworkTypeDTO](mijin_openapi_client/docs/NetworkTypeDTO.md)
 - [NetworkTypeEnum](mijin_openapi_client/docs/NetworkTypeEnum.md)
 - [NodeHealthDTO](mijin_openapi_client/docs/NodeHealthDTO.md)
 - [NodeHealthInfoDTO](mijin_openapi_client/docs/NodeHealthInfoDTO.md)
 - [NodeIdentityEqualityStrategy](mijin_openapi_client/docs/NodeIdentityEqualityStrategy.md)
 - [NodeInfoDTO](mijin_openapi_client/docs/NodeInfoDTO.md)
 - [NodeKeyLinkNetworkPropertiesDTO](mijin_openapi_client/docs/NodeKeyLinkNetworkPropertiesDTO.md)
 - [NodeKeyLinkTransactionBodyDTO](mijin_openapi_client/docs/NodeKeyLinkTransactionBodyDTO.md)
 - [NodeKeyLinkTransactionDTO](mijin_openapi_client/docs/NodeKeyLinkTransactionDTO.md)
 - [NodeStatusEnum](mijin_openapi_client/docs/NodeStatusEnum.md)
 - [NodeTimeDTO](mijin_openapi_client/docs/NodeTimeDTO.md)
 - [Order](mijin_openapi_client/docs/Order.md)
 - [Pagination](mijin_openapi_client/docs/Pagination.md)
 - [ParentPublicKeySignaturePair](mijin_openapi_client/docs/ParentPublicKeySignaturePair.md)
 - [PluginsPropertiesDTO](mijin_openapi_client/docs/PluginsPropertiesDTO.md)
 - [PositionEnum](mijin_openapi_client/docs/PositionEnum.md)
 - [ReceiptDTO](mijin_openapi_client/docs/ReceiptDTO.md)
 - [ReceiptTypeEnum](mijin_openapi_client/docs/ReceiptTypeEnum.md)
 - [RentalFeesDTO](mijin_openapi_client/docs/RentalFeesDTO.md)
 - [ResolutionEntryDTO](mijin_openapi_client/docs/ResolutionEntryDTO.md)
 - [ResolutionEntryDTOResolved](mijin_openapi_client/docs/ResolutionEntryDTOResolved.md)
 - [ResolutionStatementDTO](mijin_openapi_client/docs/ResolutionStatementDTO.md)
 - [ResolutionStatementDTOUnresolved](mijin_openapi_client/docs/ResolutionStatementDTOUnresolved.md)
 - [ResolutionStatementInfoDTO](mijin_openapi_client/docs/ResolutionStatementInfoDTO.md)
 - [ResolutionStatementPage](mijin_openapi_client/docs/ResolutionStatementPage.md)
 - [SecretLockEntryDTO](mijin_openapi_client/docs/SecretLockEntryDTO.md)
 - [SecretLockInfoDTO](mijin_openapi_client/docs/SecretLockInfoDTO.md)
 - [SecretLockNetworkPropertiesDTO](mijin_openapi_client/docs/SecretLockNetworkPropertiesDTO.md)
 - [SecretLockPage](mijin_openapi_client/docs/SecretLockPage.md)
 - [SecretLockTransactionBodyDTO](mijin_openapi_client/docs/SecretLockTransactionBodyDTO.md)
 - [SecretLockTransactionDTO](mijin_openapi_client/docs/SecretLockTransactionDTO.md)
 - [SecretProofTransactionBodyDTO](mijin_openapi_client/docs/SecretProofTransactionBodyDTO.md)
 - [SecretProofTransactionDTO](mijin_openapi_client/docs/SecretProofTransactionDTO.md)
 - [ServerDTO](mijin_openapi_client/docs/ServerDTO.md)
 - [ServerInfoDTO](mijin_openapi_client/docs/ServerInfoDTO.md)
 - [SizePrefixedEntityDTO](mijin_openapi_client/docs/SizePrefixedEntityDTO.md)
 - [SourceDTO](mijin_openapi_client/docs/SourceDTO.md)
 - [StageEnum](mijin_openapi_client/docs/StageEnum.md)
 - [StatementMetaDTO](mijin_openapi_client/docs/StatementMetaDTO.md)
 - [StorageInfoDTO](mijin_openapi_client/docs/StorageInfoDTO.md)
 - [SupplementalPublicKeysDTO](mijin_openapi_client/docs/SupplementalPublicKeysDTO.md)
 - [TransactionBodyDTO](mijin_openapi_client/docs/TransactionBodyDTO.md)
 - [TransactionDTO](mijin_openapi_client/docs/TransactionDTO.md)
 - [TransactionFeesDTO](mijin_openapi_client/docs/TransactionFeesDTO.md)
 - [TransactionGroupEnum](mijin_openapi_client/docs/TransactionGroupEnum.md)
 - [TransactionHashes](mijin_openapi_client/docs/TransactionHashes.md)
 - [TransactionIds](mijin_openapi_client/docs/TransactionIds.md)
 - [TransactionInfoDTO](mijin_openapi_client/docs/TransactionInfoDTO.md)
 - [TransactionInfoDTOMeta](mijin_openapi_client/docs/TransactionInfoDTOMeta.md)
 - [TransactionInfoDTOTransaction](mijin_openapi_client/docs/TransactionInfoDTOTransaction.md)
 - [TransactionMetaDTO](mijin_openapi_client/docs/TransactionMetaDTO.md)
 - [TransactionPage](mijin_openapi_client/docs/TransactionPage.md)
 - [TransactionPayload](mijin_openapi_client/docs/TransactionPayload.md)
 - [TransactionStatementDTO](mijin_openapi_client/docs/TransactionStatementDTO.md)
 - [TransactionStatementDTOReceiptsInner](mijin_openapi_client/docs/TransactionStatementDTOReceiptsInner.md)
 - [TransactionStatementInfoDTO](mijin_openapi_client/docs/TransactionStatementInfoDTO.md)
 - [TransactionStatementPage](mijin_openapi_client/docs/TransactionStatementPage.md)
 - [TransactionStatusDTO](mijin_openapi_client/docs/TransactionStatusDTO.md)
 - [TransactionStatusEnum](mijin_openapi_client/docs/TransactionStatusEnum.md)
 - [TransactionTypeEnum](mijin_openapi_client/docs/TransactionTypeEnum.md)
 - [TransferNetworkPropertiesDTO](mijin_openapi_client/docs/TransferNetworkPropertiesDTO.md)
 - [TransferTransactionBodyDTO](mijin_openapi_client/docs/TransferTransactionBodyDTO.md)
 - [TransferTransactionDTO](mijin_openapi_client/docs/TransferTransactionDTO.md)
 - [UnlockedAccountDTO](mijin_openapi_client/docs/UnlockedAccountDTO.md)
 - [UnresolvedMosaic](mijin_openapi_client/docs/UnresolvedMosaic.md)
 - [VerifiableEntityDTO](mijin_openapi_client/docs/VerifiableEntityDTO.md)
 - [VotingKeyLinkNetworkPropertiesDTO](mijin_openapi_client/docs/VotingKeyLinkNetworkPropertiesDTO.md)
 - [VotingKeyLinkTransactionBodyDTO](mijin_openapi_client/docs/VotingKeyLinkTransactionBodyDTO.md)
 - [VotingKeyLinkTransactionDTO](mijin_openapi_client/docs/VotingKeyLinkTransactionDTO.md)
 - [VrfKeyLinkNetworkPropertiesDTO](mijin_openapi_client/docs/VrfKeyLinkNetworkPropertiesDTO.md)
 - [VrfKeyLinkTransactionBodyDTO](mijin_openapi_client/docs/VrfKeyLinkTransactionBodyDTO.md)
 - [VrfKeyLinkTransactionDTO](mijin_openapi_client/docs/VrfKeyLinkTransactionDTO.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




